Coverage for src/paperap/resources/__init__.py: 100%

1"""

2----------------------------------------------------------------------------

3

4 METADATA:

5

6 File: __init__.py

7 Project: paperap

8 Created: 2025-03-04

9 Version: 0.0.5

10 Author: Jess Mann

11 Email: jess@jmann.me

12 Copyright (c) 2025 Jess Mann

13

14----------------------------------------------------------------------------

15

16 LAST MODIFIED:

17

18 2025-03-04 By Jess Mann

19

20"""

21

22 from paperap.resources.base import BaseResource, StandardResource

23 from paperap.resources.correspondents import CorrespondentResource

24 from paperap.resources.custom_fields import CustomFieldResource

25 from paperap.resources.document_types import DocumentTypeResource

26 from paperap.resources.documents import DocumentNoteResource, DocumentResource

27 from paperap.resources.profile import ProfileResource

28 from paperap.resources.saved_views import SavedViewResource

29 from paperap.resources.share_links import ShareLinksResource

30 from paperap.resources.storage_paths import StoragePathResource

31 from paperap.resources.tags import TagResource

32 from paperap.resources.tasks import TaskResource

33 from paperap.resources.ui_settings import UISettingsResource

34 from paperap.resources.users import GroupResource, UserResource

35 from paperap.resources.workflows import WorkflowActionResource, WorkflowResource, WorkflowTriggerResource

36

37 __all__ = [

38 "DocumentNoteResource",

39 "DocumentResource",

40 "CorrespondentResource",

41 "TagResource",

42 "DocumentTypeResource",

43 "StoragePathResource",

44 "CustomFieldResource",

45 "UserResource",

46 "GroupResource",

47 "TaskResource",

48 "SavedViewResource",

49 "UISettingsResource",

50 "WorkflowResource",

51 "WorkflowTriggerResource",

52 "WorkflowActionResource",

53]